from django import forms
from django.utils.translation import ugettext_lazy as _

from .models import Track, Jingle

def get_nonstop_zones():
    from emissions.models import Nonstop
    return [(x.id, x.title) for x in Nonstop.objects.all()]

def get_optional_nonstop_zones():
    return [('', '')] + get_nonstop_zones()

def get_search_nonstop_zones():
    return [('', 'All'),
            ('any', _('Any')),
            ('', '--------------')] + get_nonstop_zones() + [('', '--------------'), ('none', 'None')]

class UploadTracksForm(forms.Form):
    tracks = forms.FileField(widget=forms.ClearableFileInput(
        attrs={'multiple': True, 'accept': 'audio/*'}))
    nonstop_zone = forms.ChoiceField(choices=get_optional_nonstop_zones)


class TrackMetaForm(forms.ModelForm):
    class Meta:
        model = Track
        fields = ['language', 'instru', 'sabam', 'cfwb', 'nonstop_zones']


class TrackSearchForm(forms.Form):
    q = forms.CharField(label=_('Text'), required=False)
    zone = forms.ChoiceField(label=_('Nonstop Zone'),
            choices=get_search_nonstop_zones, required=False)
    order_by = forms.ChoiceField(label=_('Order'),
            required=False,
            choices=[('title', _('Alphabetically')),
                     ('-added_to_nonstop_timestamp', _('Newest first')),
                     ('added_to_nonstop_timestamp', _('Oldest first'))])


class CleanupForm(forms.Form):
    zone = forms.ChoiceField(label=_('Nonstop Zone'), choices=get_optional_nonstop_zones)
